@@ -40,12 +40,17 @@ class KIMAP_EXPORT SelectJob : public Job
 
 public:
     explicit SelectJob(Session *session);
-    virtual ~SelectJob();
+    ~SelectJob() override;
 
     void setMailBox(const QString &mailBox);
     QString mailBox() const;
 
     void setOpenReadOnly(bool readOnly);
+    /**
+     * @return Returns whether the mailbox is opened in read-only mode. Note
+     * that this can return true even if setOpenReadOnly() was set to false,
+     * as the mailbox may be read-only on the server.
+     */
     bool isOpenReadOnly() const;
 
     QList<QByteArray> flags() const;
