@@ -53,10 +53,19 @@
 
 using namespace KIMAP;
 
+using PartsReceivedSignal = void(FetchJob::*)(const QString &, const QMap<qint64,qint64> &,
+                                              const QMap<qint64, MessageParts> &);
+
+using HeadersReceivedSignal = void(FetchJob::*)(const QString &,
+                                                const QMap<qint64, qint64> &,
+                                                const QMap<qint64, qint64> &,
+                                                const QMap<qint64, MessageFlags> &,
+                                                const QMap<qint64, MessagePtr> &);
+
 class UiProxy: public SessionUiProxy
 {
 public:
-    bool ignoreSslError(const KSslErrorUiData &errorData) Q_DECL_OVERRIDE
+    bool ignoreSslError(const KSslErrorUiData &errorData) override
     {
         Q_UNUSED(errorData);
         return true;
@@ -147,9 +156,9 @@ void testAcl(Session *session, const QString &user)
     listRights->setIdentifier(user.toLatin1());
     listRights->exec();
     qDebug() << "Default rights on INBOX/TestFolder: " << Acl::rightsToString(listRights->defaultRights());
-    QList<Acl::Rights> possible = listRights->possibleRights();
+    const QList<Acl::Rights> possible = listRights->possibleRights();
     QStringList strList;
-    Q_FOREACH (Acl::Rights r, possible) {
+    for (Acl::Rights r : qAsConst(possible)) {
         strList << QString::fromLatin1(Acl::rightsToString(r));
     }
     qDebug() << "Possible rights on INBOX/TestFolder: " << strList;
@@ -242,8 +251,14 @@ void testAppendAndStore(Session *session)
     scope.parts.clear();
     scope.mode = FetchJob::FetchScope::Content;
     fetch->setScope(scope);
+    MessagePtr message;
+    QObject::connect(fetch, static_cast<HeadersReceivedSignal>(&FetchJob::headersReceived),
+                     fetch, [&](const QString &, const QMap<qint64, qint64> &,
+                                const QMap<qint64, qint64> &, const QMap<qint64, MessageFlags> &,
+                                const QMap<qint64, MessagePtr> &msgs) {
+                        message = msgs[1];
+                    });
     fetch->exec();
-    MessagePtr message = fetch->messages()[1];
     Q_ASSERT_X(fetch->error() == 0, "FetchJob", fetch->errorString().toLocal8Bit().constData());
     testMailContent.replace("\r\n", "\n");
     Q_ASSERT_X(testMailContent == message->head() + "\n" + message->body(),
@@ -254,13 +269,19 @@ void testAppendAndStore(Session *session)
     scope.parts.clear();
     scope.mode = FetchJob::FetchScope::Flags;
     fetch->setScope(scope);
+    MessageFlags expectedFlags;
+    QObject::connect(fetch, static_cast<HeadersReceivedSignal>(&FetchJob::headersReceived),
+                     fetch, [&](const QString &, const QMap<qint64, qint64> &,
+                                const QMap<qint64, qint64> &, const QMap<qint64, MessageFlags> &flags,
+                                const QMap<qint64, MessagePtr> &) {
+                        expectedFlags = flags[1];
+                    });
     fetch->exec();
-    MessageFlags expectedFlags = fetch->flags()[1];
     qDebug() << "Read the message flags:" << expectedFlags;
 
     qDebug() << "Add the \\Deleted flag...";
     expectedFlags << "\\Deleted";
-    qSort(expectedFlags);
+    std::sort(expectedFlags.begin(), expectedFlags.end());
     StoreJob *store = new StoreJob(session);
     store->setSequenceSet(ImapSet(1));
     store->setMode(StoreJob::AppendFlags);
@@ -269,7 +290,7 @@ void testAppendAndStore(Session *session)
     Q_ASSERT_X(store->error() == 0, "StoreJob", store->errorString().toLocal8Bit().constData());
 
     QList<QByteArray> resultingFlags = store->resultingFlags()[1];
-    qSort(resultingFlags);
+    std::sort(resultingFlags.begin(), resultingFlags.end());
     if (expectedFlags != resultingFlags) {
         qDebug() << resultingFlags;
     }
@@ -385,8 +406,9 @@ int main(int argc, char **argv)
     QString server = QString::fromLocal8Bit(argv[1]);
     int port = 143;
     if (server.count(QLatin1Char(':')) == 1) {
-        port = server.split(QLatin1Char(':')).last().toInt();
-        server = server.split(QLatin1Char(':')).first();
+        const QStringList lstSplit = server.split(QLatin1Char(':'));
+        port = lstSplit.last().toInt();
+        server = lstSplit.first();
     }
     QString user = QString::fromLocal8Bit(argv[2]);
     QString password = QString::fromLocal8Bit(argv[3]);
@@ -481,12 +503,22 @@ int main(int argc, char **argv)
     scope.parts.clear();
     scope.mode = FetchJob::FetchScope::Headers;
     fetch->setScope(scope);
+    QMap<qint64, qint64> sizes;
+    QMap<qint64, MessagePtr> messages;
+
+    QObject::connect(fetch, static_cast<HeadersReceivedSignal>(&FetchJob::headersReceived),
+                     fetch, [&](const QString &, const QMap<qint64,qint64> &,
+                                const QMap<qint64, qint64> &sizes_,
+                                const QMap<qint64, MessageFlags> &,
+                                const QMap<qint64, MessagePtr> &msgs_) {
+                         sizes = sizes_;
+                         messages = msgs_;
+                     });
     fetch->exec();
     Q_ASSERT_X(fetch->error() == 0, "FetchJob", fetch->errorString().toLocal8Bit().constData());
     Q_ASSERT(session.state() == Session::Selected);
-    QMap<qint64, MessagePtr> messages = fetch->messages();
     foreach (qint64 id, messages.keys()) {
-        qDebug() << "* Message" << id << "(" << fetch->sizes()[id] << "bytes )";
+        qDebug() << "* Message" << id << "(" << sizes[id] << "bytes )";
         qDebug() << "  From      :" << messages[id]->from()->asUnicodeString();
         qDebug() << "  To        :" << messages[id]->to()->asUnicodeString();
         qDebug() << "  Date      :" << messages[id]->date()->asUnicodeString();
@@ -501,10 +533,17 @@ int main(int argc, char **argv)
     scope.parts.clear();
     scope.mode = FetchJob::FetchScope::Flags;
     fetch->setScope(scope);
+    QMap<qint64, MessageFlags> flags;
+    QObject::connect(fetch, static_cast<HeadersReceivedSignal>(&FetchJob::headersReceived),
+                     fetch, [&](const QString &, const QMap<qint64,qint64> &,
+                                const QMap<qint64, qint64> &,
+                                const QMap<qint64, MessageFlags> &flags_,
+                                const QMap<qint64, MessagePtr> &) {
+                         flags = flags_;
+                     });
     fetch->exec();
     Q_ASSERT_X(fetch->error() == 0, "FetchJob", fetch->errorString().toLocal8Bit().constData());
     Q_ASSERT(session.state() == Session::Selected);
-    QMap<qint64, MessageFlags> flags = fetch->flags();
     foreach (qint64 id, flags.keys()) {
         qDebug() << "* Message" << id << "flags:" << flags[id];
     }
@@ -516,10 +555,17 @@ int main(int argc, char **argv)
     scope.parts.clear();
     scope.mode = FetchJob::FetchScope::Structure;
     fetch->setScope(scope);
+    QObject::connect(fetch, static_cast<HeadersReceivedSignal>(&FetchJob::headersReceived),
+                     fetch, [&](const QString &, const QMap<qint64,qint64> &,
+                                const QMap<qint64, qint64> &,
+                                const QMap<qint64, MessageFlags> &,
+                                const QMap<qint64, MessagePtr> &msgs_) {
+                         messages = msgs_;
+                     });
     fetch->exec();
     Q_ASSERT_X(fetch->error() == 0, "FetchJob", fetch->errorString().toLocal8Bit().constData());
     Q_ASSERT(session.state() == Session::Selected);
-    MessagePtr message = fetch->messages()[1];
+    MessagePtr message = messages[1];
     dumpContentHelper(message.data());
     qDebug();
 
@@ -530,10 +576,15 @@ int main(int argc, char **argv)
     scope.parts << "2";
     scope.mode = FetchJob::FetchScope::Headers;
     fetch->setScope(scope);
+    QMap<qint64, MessageParts> allParts;
+    QObject::connect(fetch, static_cast<PartsReceivedSignal>(&FetchJob::partsReceived),
+                     fetch, [&](const QString &, const QMap<qint64, qint64> &,
+                                const QMap<qint64, MessageParts> &parts_) {
+                         allParts = parts_;
+                     });
     fetch->exec();
     Q_ASSERT_X(fetch->error() == 0, "FetchJob", fetch->errorString().toLocal8Bit().constData());
     Q_ASSERT(session.state() == Session::Selected);
-    QMap<qint64, MessageParts> allParts = fetch->parts();
     foreach (qint64 id, allParts.keys()) {
         qDebug() << "* Message" << id << "parts headers";
         MessageParts parts = allParts[id];
@@ -553,10 +604,14 @@ int main(int argc, char **argv)
     scope.parts << "2";
     scope.mode = FetchJob::FetchScope::Content;
     fetch->setScope(scope);
+    QObject::connect(fetch, static_cast<PartsReceivedSignal>(&FetchJob::partsReceived),
+                     fetch, [&](const QString &, const QMap<qint64, qint64> &,
+                                const QMap<qint64, MessageParts> &parts_) {
+                         allParts = parts_;
+                     });
     fetch->exec();
     Q_ASSERT_X(fetch->error() == 0, "FetchJob", fetch->errorString().toLocal8Bit().constData());
     Q_ASSERT(session.state() == Session::Selected);
-    allParts = fetch->parts();
     foreach (int id, allParts.keys()) {
         MessageParts parts = allParts[id];
         foreach (const QByteArray &partId, parts.keys()) {
